@@ -1,14 +1,24 @@
-# E.Blondel - 2014/08/20
-#=======================
-
-SDMXCode <- function(xmlObj){
+#' @name SDMXCode
+#' @rdname SDMXCode
+#' @aliases SDMXCode,SDMXCode-method
+#' 
+#' @usage
+#' SDMXCode(xmlObj, namespaces)
+#' 
+#' @param xmlObj object of class "XMLInternalDocument derived from XML package
+#' @param namespaces object of class "data.frame" given the list of namespace URIs
+#' @return an object of class "SDMXCode"
+#' 
+#' @seealso \link{readSDMX}
+#'
+SDMXCode <- function(xmlObj, namespaces){
   
-  sdmxVersion <- version.SDMXSchema(xmlDoc(xmlObj))
-  VERSION.21 <- sdmxVersion == "2.1"
-  
-  namespaces <- namespaces.SDMX(xmlDoc(xmlObj))
   messageNs <- findNamespace(namespaces, "message")
   strNs <- findNamespace(namespaces, "structure")
+  
+  sdmxVersion <- version.SDMXSchema(xmlDoc(xmlObj), namespaces)
+  VERSION.21 <- sdmxVersion == "2.1"
+  
   refNs <- strNs
   if(VERSION.21){
     comNs <- findNamespace(namespaces, "common")
